/**
 * @file
 *
 * Highwire Article Pre-Val Widget.
 */

(function ($) {
  Drupal.behaviors.highwire_article_preval = {
    attach: function (context, settings) {
       $(".highwire-prelocation", context).each(function(index){
         var $this = $(this);
         var logoType = $this.data('logo-type');
         var mouseOver = $this.data('mouseover');
         var doi = $this.data('doi');
         var settings = {
           settings: {
             logoType: logoType,
             mouseOver: mouseOver,
           },
           doi: doi
         };
         $this.preAPI(settings);
       });
    }
  };
})(jQuery);;
/**
 * @file
 * HW PDF tab treatment.
 *
 * Copyright (c) HighWire Press, Inc.
 * This software is open-source licensed under the GNU Public License Version 2 or later
 * The full license is available in the LICENSE.TXT file at the root of this repository
 */
(function ($) {
  Drupal.behaviors.highwire_panels_ajax_tab = {
    attach: function (context, settings) {
      $('a.panels-ajax-tab-tab', context, settings).once('hw-panels-ajax-tabs-once', function() {
        if (typeof(settings.highwire_panel_tabs) != "undefined") {
          for (var i = settings.highwire_panel_tabs.length -1; i >= 0; i--) {
            var panel_name = settings.highwire_panel_tabs[i].panel_name;
            if ($(this).data('panel-name') == panel_name) {
              $(this).unbind('click').attr('target', '_blank');
            }
          }
        }
      });
      $('a.highwire-article-nav-jumplink', context, settings).once('hw-panels-ajax-tabs-once', function() {
        if (typeof(settings.highwire_panel_tabs) != "undefined") {
          var panel_ajax_tab = settings.highwire_panel_tabs.panel_ajax_tab;
          if ($(this).data('panel-ajax-tab') == panel_ajax_tab) {
            $(this).unbind('click').attr('target', '_blank');
          }
        }
      });
    }
  };
})(jQuery);
;
/**
 * @file
 * Highwire Google Scholar citation sprinkle links
 *
 * Copyright (c) HighWire Press, Inc
 * This software is open-source licensed under the GNU Public License Version 2
 * or later. The full license is available in the LICENSE.TXT file at the root
 * of this repository.
 */

(function ($) {
  Drupal.behaviors.highwire_google_scholar = { attach: function (context, settings) {
    if($('.cit-extra').length > 0){
      $('.cit-list .ref-cit').once('google_scholar_link',function() {
        $(this).each(function() {

        // Pull the set of authors to submit as an array.
        var authorList = '';
        var c = 0;
        $(this).find('.cit-auth').each(function () {

          var given = $(this).find('.cit-name-given-names') !== 'undefined' ? $(this).find('.cit-name-given-names').html() : '';
          var sur = $(this).find('.cit-name-surname') !== 'undefined' ? $(this).find('.cit-name-surname').html() : '';
          if(given || sur) {
            authorList += '&author[' + c + ']=' + (given ? given : '') + (sur ? '+' + sur : '');
          } else if ($(this).hasClass('cit-collab')) {
            authorList += '&author[' + c + ']=' + $(this).text();
          }
          c++;
        });

        var articleTitle = $(this).find('.cit-article-title').length > 0 ? $(this).find('.cit-article-title').text() : false;

        var articlePub = $(this).find('.cit-pub-date').length > 0 ? $(this).find('.cit-pub-date').html() : false;

        // We need all three values to submit a lookup.
        if (articleTitle !== false
          && articlePub !== false
          && authorList !== '') {
        // Regex used to strip inlne html tags from article title.
          var gs = {
            gsAuthor: authorList,
            gsTitle: articleTitle.replace(/< *img[^>]*src *= *["\']?([^"\']*)"\/>/i, '').replace(/\ /g, '+'),
            publicationYear: articlePub
          };

          // Additional, non-required fields that are available in various
          // citation formats.
          extraFields = {
            journal: $(this).find('.cit-jnl-abbrev').length > 0 ? $(this).find('.cit-jnl-abbrev').html() : false,
            volume: $(this).find('.cit-vol').length > 0 ? $(this).find('.cit-vol').html() : false,
            issn: $(this).find('.cit-issn').length > 0 ? $(this).find('.cit-issn').html() : false,
            isbn: $(this).find('.cit-isbn').length > 0 ? $(this).find('.cit-isbn').html() : false,
            doi: $(this).find('.cit-doi').length > 0 ? $(this).find('.cit-doi').html() : false,
            pages: ($(this).find('.cit-fpage').length > 0 && $(this).find('.cit-lpage').length > 0)? $(this).find('.cit-fpage').html() + '-' +  $(this).find('.cit-lpage').html() : false
          };

          extraFieldString = '';
          $.each(extraFields, function (idx, val){
            if (val !== false) {
              extraFieldString += '&' + idx + '=' + val.replace(/\ /g, '+');
            }
          });

          var gs_link = '<a href="/lookup/google-scholar?link_type=googlescholar&gs_type=article' + gs.gsAuthor + '&title=' + gs.gsTitle + '&publication_year=' + gs.publicationYear + extraFieldString + '" target="_blank" class="cit-ref-sprinkles cit-ref-sprinkles-google-scholar cit-ref-sprinkles-google-scholar"><span>Google Scholar</span></a>';

          $(this, context).once('custom-js', function(){
            $(this).find('.cit-extra').append(gs_link);
          });
        }         
        });
      });
    }
  }}
})(jQuery);
;
/**
 * Highwire OpenURL
 *
 * Copyright (c) HighWire Press, Inc
 * This software is open-source licensed under the GNU Public License Version 2
 * or later. The full license is available in the LICENSE.TXT file at the root
 * of this repository.
 */

(function ($) {
  Drupal.behaviors.highwire_openurl = { attach: function (context, settings) {
    if ($('.cit-ref-sprinkles-open-url').length > 0) {
      // Get the insitutional OpenURL branding data
      var id = '';
      if ("apath" in Drupal.settings.highwire) {
        id = '?apath=' + encodeURIComponent(Drupal.settings.highwire.apath);
      }
      $.getJSON(

        Drupal.settings.basePath + 'highwire/openurl_branding' + id,
        function(data){
          if(data){
            // Add to Drupal.settings in case we have another use for it
            Drupal.settings.highwireOpenurl = data;

            // Not all journals have OpenURL implementations
            if (data.base_url === null) {
              $('.cit-ref-sprinkles-open-url').hide();
            }
            else {
              // Update each link to show institutional branding
              $('.cit-ref-sprinkles-open-url').each(function(){
                var $link = $(this);
                $link.once('insertImage', function(){
                  var branding = Drupal.settings.highwireOpenurl;
                  var href = $link.attr('href');
                  var placeholder = '';
                  var queryKey = '';

                  // Check if this is content from old markup server.
                  if (href.indexOf('{openurl}') != -1) {
                    // Set placeholder accordingly.
                    placeholder = '{openurl}';
                    // The href from the old markup server is encoded twice, so decode twice.
                    href = decodeURIComponent(href);
                    href = decodeURIComponent(href);
                  }
                  // Check if this is content from the new markup server.
                  // @see JIRA ticket: GP-86
                  else if (href.indexOf('urn:openurl:') != -1) {
                    // Set placeholdet text and query key accordingly.
                    placeholder = 'urn:openurl:';
                    queryKey = '?';
                  }
                  // Update openURL link with new href and text.
                  href = href.replace('?query=','?');
                  href = href.replace(placeholder, Drupal.settings.basePath + 'highwire/openurl' + queryKey);
                  var openurl_link = href + '&redirect_url=' + branding.base_url;
                  $link.attr('href', openurl_link.replace(/\+/g,  " "));
                  $link.text(branding.link_text);
                  if(branding.image){
                    $link.prepend('<img src="' + branding.image + '"/>');
                  }
                });
              });
            }
          }
        }
      );
    }
  }}
})(jQuery);
;
var bodyTags = document.getElementsByTagName('body');
var body = bodyTags[0];
var trendmd_instances  = Drupal.settings.highwire.trendmd;

for (var id in trendmd_instances){
  if (trendmd_instances.hasOwnProperty(id)) {
    var s = document.createElement('script');
    s.type = 'text/javascript';
    s.src = "//js.trendmd.com/trendmd.min.js";
    s.defer = 'defer';
    s.setAttribute('data-trendmdconfig', trendmd_instances[id]);
    body.insertBefore(s, body.lastChild.nextSibling);
  }
}
;
